@@ -195,7 +195,7 @@ def quads_to_tris(quads):
         tris[j+1,2] = n0
     return tris
 
-def plot2D_deform(up,defo,cnx,ax,color='RdYlGn_r',bar_label='Resultados',logo=True,labels=False):
+def plot2D_deform(up,defo,cnx,ax,color='RdYlGn_r',bar_label='Resultados',logo=True,labels=False,elems=True):
     '''
     Función que realiza el ploteo de nodos, elementos y resultados.
     '''
@@ -209,7 +209,8 @@ def plot2D_deform(up,defo,cnx,ax,color='RdYlGn_r',bar_label='Resultados',logo=Tr
     norm = colors.Normalize(vmin=min(up), vmax=max(up))
     plt.colorbar(matplotlib.cm.ScalarMappable(norm=norm, cmap=color),
                     orientation='vertical',label=bar_label)
-    graph(defo,cnx,ax,logo=logo,labels=labels)
+    if elems==True:
+        graph(defo,cnx,ax,logo=logo,labels=labels)
     plt.axis('off'); plt.axis('equal')
-    plt.tight_layout(); plt.show()
+    plt.tight_layout()
 
